==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/my_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_membership_info'] = 					"membership information";
$lang['hdr_membership'] = 						"membership";
$lang['hdr_email_info'] = 						"email settings";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_sub_rss'] = 							"your rss feeds";
$lang['hdr_sub_email'] = 						"your email subscriptions";


//HREF
$lang['href_edit_membership'] = 				"edit membership";


//BODY TEXT
$lang['txt_confirm_email'] =					"confirm email";
$lang['txt_confirm_password'] =					"confirm password";
$lang['txt_dob'] =								"date of birth";
$lang['txt_email'] =							"email";
$lang['txt_firstname'] =						"firstname";
$lang['txt_password'] =							"password";
$lang['txt_pref_lang'] =						"preferred language";
$lang['txt_surname'] =							"surname";
$lang['txt_template'] =							"template";
$lang['txt_lang_selection'] = 					"languages";
$lang['txt_membership_number'] =				"membership number";
$lang['txt_homepage'] = 						"home page";
$lang['txt_rss_help'] = 						"An RSS feed is available for this community. Please note, if you change your password you will need to recreate this feed. See the help group for more information on RSS.";
$lang['txt_hometown_help'] =					"Home town hint: Your home town is the place where you are living now.";
$lang['txt_password_help'] =					"Password hint: Use something that no one will guess. Your password has to be at least 5 characters long.";
$lang['txt_lang_help'] =						"Language hint: Select you preferred language to see the screens displayed in that language. Articles will be displayed written in the languages you select from the 'languages' option.";
$lang['txt_template_help'] =					"Template hint: A template is like a 'theme'; if is the look and feel of the screens.";
$lang['txt_email_set_help'] = 					"You can change your email address at any time. Type in your new email address and confirm. When you press 'update' you will be sent an email to that email address. You need to press the link in the email address to log back in with you new email address.";
$lang['txt_email_message_help'] = 				"Check the box to send you a notification email when you receive a message.";
$lang['txt_digest_newsletter_help'] = 			"Check the box to receive a weekly digest newsletter containing movement against your bookmarks, new events, group information and statistics.";


// MESSAGES AND EMAIL
$lang['subject_new_details'] = 						"Your new AROUNDMe details!";

?>

==> aroundme_0_6_4.tar.tgz: aroundme_0_6_4/aroundme/language/1/barnraiser_01/my_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_membership_info'] = 					"membership information";
$lang['hdr_membership'] = 						"membership";
$lang['hdr_email_info'] = 						"email settings";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_sub_rss'] = 							"your rss feeds";
$lang['hdr_sub_email'] = 						"your email subscriptions";


//HREF
$lang['href_edit_membership'] = 				"edit membership";


//BODY TEXT
$lang['txt_confirm_email'] =					"confirm email";
$lang['txt_confirm_password'] =					"confirm password";
$lang['txt_dob'] =								"date of birth";
$lang['txt_email'] =							"email";
$lang['txt_firstname'] =						"firstname";
$lang['txt_password'] =							"password";
$lang['txt_pref_lang'] =						"preferred language";
$lang['txt_surname'] =							"surname";
$lang['txt_template'] =							"template";
$lang['txt_lang_selection'] = 					"languages";
$lang['txt_membership_number'] =				"membership number";
$lang['txt_homepage'] = 						"home page";
$lang['txt_hometown_help'] =					"Home town hint: Your home town is the place where you are living now.";
$lang['txt_password_help'] =					"Password hint: Use something that no one will guess. Your password has to be at least 5 characters long.";
$lang['txt_lang_help'] =						"Language hint: Select you preferred language to see the screens displayed in that language. Articles will be displayed written in the languages you select from the 'languages' option.";
$lang['txt_template_help'] =					"Template hint: A template is like a 'theme'; if is the look and feel of the screens.";
$lang['txt_email_set_help'] = 					"You can change your email address at any time. Type in your new email address and confirm. When you press 'update' you will be sent an email to that email address. You need to press the link in the email address to log back in with you new email address.";
$lang['txt_email_message_help'] = 				"Check the box to send you a notification email when you receive a message.";
$lang['txt_digest_newsletter_help'] = 			"Check the box to receive a weekly digest newsletter containing movement against your bookmarks, new events, group information and statistics.";
$lang['txt_rss_help'] = 						"An RSS feed is available for this node. Please note, if you change your password you will need to recreate this feed. See the help group for more information on RSS.";
$lang['txt_public_rss_help'] = 					"An public RSS feed is available for this node. Please note, if you log in you can get a feed which contains non public content. See the help section for more information RSS.";


// MESSAGES AND EMAIL
$lang['subject_new_details'] = 						"Your new AROUNDMe details!";

?>
